==> ecuapassdocs-0.51.tar.gz: ecuapassdocs-0.51/ecuapassdocs/info/ecuapass_info_manifiesto_SYTSA.py <==
#!/usr/bin/env python3

import re, os, json, sys
from traceback import format_exc as traceback_format_exc

from .ecuapass_info_manifiesto_NTA import ManifiestoNTA
from .ecuapass_data import EcuData
from .ecuapass_utils import Utils
from .ecuapass_extractor import Extractor  # Extracting basic info from text

#----------------------------------------------------------
USAGE = "\
Extract information from document fields analized in AZURE\n\
USAGE: ecuapass_info_manifiesto.py <Json fields document>\n"
#----------------------------------------------------------
def main ():
	args = sys.argv
	fieldsJsonFile = args [1]
	runningDir = os.getcwd ()
	mainFields = EcuMNF.getMainFields (fieldsJsonFile, runningDir)
	Utils.saveFields (mainFields, fieldsJsonFile, "Results")

#----------------------------------------------------------
# Class that gets main info from Ecuapass document 
#----------------------------------------------------------
class ManifiestoSytsa (ManifiestoNTA):
	def __init__(self, fieldsJsonFile, runningDir):
		super().__init__ (fieldsJsonFile, runningDir)
		self.empresa   = EcuData.getEmpresaInfo ("SYTSA")

	#-----------------------------------------------------------
	#-- Get 'total bultos' and 'tipo embalaje' -----------------
	#-----------------------------------------------------------
	def getBultosInfo (self):
		bultosInfo = super().getBultosInfo ()
		bultosInfo ["embalaje"] = bultosInfo ["marcas"]

		return bultosInfo
#--------------------------------------------------------------------
# Call main 
#--------------------------------------------------------------------
if __name__ == '__main__':
	main ()

==> ecuapassdocs-0.71.tar.gz: ecuapassdocs-0.71/ecuapassdocs/info/ecuapass_info_manifiesto_SYTSA.py <==
#!/usr/bin/env python3

import re, os, json, sys
from traceback import format_exc as traceback_format_exc

from .ecuapass_info_manifiesto_NTA import ManifiestoNTA
from .ecuapass_data import EcuData
from .ecuapass_utils import Utils
from .ecuapass_extractor import Extractor  # Extracting basic info from text

#----------------------------------------------------------
USAGE = "\
Extract information from document fields analized in AZURE\n\
USAGE: ecuapass_info_manifiesto.py <Json fields document>\n"
#----------------------------------------------------------
def main ():
	args = sys.argv
	fieldsJsonFile = args [1]
	runningDir = os.getcwd ()
	mainFields = ManifiestoInfo.getMainFields (fieldsJsonFile, runningDir)
	Utils.saveFields (mainFields, fieldsJsonFile, "Results")

#----------------------------------------------------------
# Class that gets main info from Ecuapass document 
#----------------------------------------------------------
class ManifiestoSytsa (ManifiestoNTA):
	def __init__(self, fieldsJsonFile, runningDir):
		super().__init__ (fieldsJsonFile, runningDir)
		self.empresa   = EcuData.getEmpresaInfo ("SYTSA")

	#-----------------------------------------------------------
	#-- Get 'total bultos' and 'tipo embalaje' -----------------
	#-----------------------------------------------------------
	def getBultosInfo (self):
		bultosInfo = super().getBultosInfo ()
		bultosInfo ["embalaje"] = bultosInfo ["marcas"]

		return bultosInfo
#--------------------------------------------------------------------
# Call main 
#--------------------------------------------------------------------
if __name__ == '__main__':
	main ()
